@@ -1,23 +1,13 @@
 /*
-    Copyright 20011 Julian Helfferich <julian.helfferich@gmail.com>
+    SPDX-FileCopyrightText: 20011 Julian Helfferich <julian.helfferich@gmail.com>
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef LEVELLOADER_H
 #define LEVELLOADER_H
 
+// Qt
 #include <QObject>
 
 class QDomDocument;
@@ -28,7 +18,7 @@ class LevelLoader : public QObject
     Q_OBJECT
 public:
     explicit LevelLoader(QObject *parent = nullptr);
-    ~LevelLoader();
+    ~LevelLoader() override;
 
     int level() const;
     void setLevel(int level);
